<?php
//namespace\Saasland_core::instance();


class Saasland_Enqueue_Scripts {

    private static $_instance = null;
    public static function instance() {

        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;

    }

    public function __construct() {
        add_action( 'plugins_loaded', [ $this, 'on_plugins_loaded' ] );
    }

    public function on_plugins_loaded() {
        add_action( 'init', [$this, 'register_scripts'] );
    }

    public function register_scripts () {

        // Register Widget Scripts
        add_action( 'elementor/frontend/after_register_scripts', [ $this, 'register_widget_scripts' ] );
        add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'register_widget_scripts' ] );

        add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_scripts' ] );

        add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'enqueue_elementor_scripts' ]);
        add_action( 'elementor/frontend/after_enqueue_scripts', [ $this, 'enqueue_elementor_scripts' ]);

        // Register Widget Scripts
        add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'enqueue_elementor_editor_styles' ] );
        add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'enqueue_widget_styles' ] );

    }


    /**
     *
     */
    function enqueue_widget_styles() {

        if ( is_page_template( 'page-split.php') ) {
            wp_enqueue_style( 'multiscroll', SAASLAND_CORE_DIR_VEND . '/multiscroll/jquery.multiscroll.css');
        }

        wp_enqueue_style( 'simple-line-icon', SAASLAND_CORE_DIR_VEND . '/simple-line-icon/simple-line-icons.min.css' );
        wp_register_style( 'slick', SAASLAND_CORE_DIR_VEND . '/slick/slick.min.css');
        wp_enqueue_style( 'slick-theme', SAASLAND_CORE_DIR_VEND . '/slick/slick-theme.css');
        wp_register_style( 'owl-carousel', SAASLAND_CORE_DIR_VEND .  '/owl-carousel/assets/owl.carousel.min.css' );
        wp_enqueue_style( 'themify-icons', SAASLAND_CORE_DIR_VEND . '/themify-icon/themify-icons.css');
        wp_enqueue_style( 'saasland-flaticons', SAASLAND_CORE_DIR_VEND . '/flaticon/flaticon.css');
        wp_enqueue_style( 'saasland-icomoon', SAASLAND_CORE_DIR_VEND . '/icomoon/style.css' );
        wp_register_style( 'splitting', SAASLAND_CORE_DIR_VEND . '/splitting/splitting.css' );

        wp_register_style( 'appart-style', SAASLAND_CORE_DIR_CSS . '/appart-style.css' );
        wp_register_style( 'appart-responsive', SAASLAND_CORE_DIR_CSS . '/appart-responsive.min.css' );
        wp_register_style( 'saasland-demo', SAASLAND_CORE_DIR_JS . '/saasland-demo.min.css' );

        if ( is_rtl() ) {
            wp_enqueue_style( 'appart-rtl', SAASLAND_CORE_DIR_CSS . '/appart-rtl.min.css', array('appart-style') );
        }

        // Section Dependency CSS
        wp_register_style( 'hero-chat', SAASLAND_CORE_DIR_CSS . '/widgets/hero-chat.css' );
        wp_register_style( 'hero-event', SAASLAND_CORE_DIR_CSS . '/widgets/hero-event.css' );
        wp_register_style( 'saasland-hero', SAASLAND_CORE_DIR_CSS . '/widgets/hero.css' );
        wp_register_style( 'price-table-event', SAASLAND_CORE_DIR_CSS . '/widgets/price-table-event.css' );
        wp_register_style( 'parallax-image', SAASLAND_CORE_DIR_CSS . '/widgets/parallax-image.css' );
        wp_register_style( 'curve-counter-event', SAASLAND_CORE_DIR_CSS . '/widgets/curve-counter-event.css' );
        wp_register_style( 'date-countdown', SAASLAND_CORE_DIR_CSS . '/widgets/date-countdown.css' );
        wp_register_style( 'event-schedule', SAASLAND_CORE_DIR_CSS . '/widgets/event-schedule.css' );
        wp_register_style( 'team', SAASLAND_CORE_DIR_CSS . '/widgets/team.css' );
        wp_register_style( 'tilt-image2', SAASLAND_CORE_DIR_CSS . '/widgets/tilt-images2.css' );
        wp_register_style( 'chat-features', SAASLAND_CORE_DIR_CSS . '/widgets/chat-features.css' );
        wp_register_style( 'saasland-testimonials', SAASLAND_CORE_DIR_CSS . '/widgets/testimonials.css' );
        wp_register_style( 'saasland-core-portfolio', SAASLAND_CORE_DIR_CSS . '/widgets/portfolio.css' );
        wp_register_style( 'saasland-images', SAASLAND_CORE_DIR_CSS . '/widgets/images.css' );
        wp_register_style( 'saasland-tabs', SAASLAND_CORE_DIR_CSS . '/widgets/tabs.css' );
        wp_register_style( 'saas-button', SAASLAND_CORE_DIR_CSS . '/widgets/button.css' );
        wp_register_style( 'saasland-blog', SAASLAND_CORE_DIR_CSS . '/widgets/blog-style.css' );

        /**
         * Enqueue Style's
         */
        if ( defined( 'ELEMENTOR_VERSION') ) {
            if ( \Elementor\Plugin::$instance->preview->is_preview_mode() ) {
                wp_enqueue_style( 'owl-carousel' );
                wp_enqueue_style( 'appart-style' );
                wp_enqueue_style( 'appart-responsive' );
                wp_enqueue_style( 'saasland-digital-agency' );
            }
        }

    }


    /**
     * Register Widget Scripts
     *
     * Register custom scripts required to run Saasland Core.
     *
     * @access public
     */
    function register_widget_scripts() {

        /*if ( !is_admin() ) {
            wp_deregister_script( 'jquery' );
            wp_register_script( 'jquery', SAASLAND_CORE_DIR_JS . '/jquery-3.2.1.min.js', false, '3.4.1' );
            wp_enqueue_script( 'jquery' );
        }*/

        wp_register_script( 'slick', SAASLAND_CORE_DIR_VEND . '/slick/slick.min.js', 'jquery', '1.9.0', true );
        wp_register_script( 'owl-carousel', SAASLAND_CORE_DIR_VEND . '/owl-carousel/owl.carousel.min.js', 'jquery', '2.3.4', true );
        wp_register_script( 'waypoints', SAASLAND_CORE_DIR_VEND . '/counterup/jquery.waypoints.min.js', 'jquery', '4.0.1', true );
        wp_register_script( 'counterup', SAASLAND_CORE_DIR_VEND . '/counterup/jquery.counterup.min.js', 'jquery', '1.0', true );
        wp_register_script( 'appear', SAASLAND_CORE_DIR_VEND . '/counterup/appear.js', 'jquery', '1.0', true );
        wp_register_script( 'parallaxie', SAASLAND_CORE_DIR_VEND . '/parallax/parallaxie.js', 'jquery', '0.5', true );
        wp_register_script( 'parallax-scroll', SAASLAND_CORE_DIR_VEND . '/parallax/parallax-scroll.js', 'jquery', '1.0', true );
        wp_register_script( 'parallax', SAASLAND_CORE_DIR_VEND . '/parallax/parallax.js', 'jquery', '1.0', true );
        wp_register_script( 'stellar', SAASLAND_CORE_DIR_VEND . '/stellar/jquery.stellar.js', 'jquery', '1.0', true );
        wp_register_script( 'circle-progress', SAASLAND_CORE_DIR_VEND . '/circle-progress/circle-progress.js', 'jquery', '1.1.3', true );
        wp_register_script( 'isotope', SAASLAND_CORE_DIR_VEND . '/isotope/isotope-min.js', 'jquery', '3.0.1', true );
        wp_register_script( 'splitting', SAASLAND_CORE_DIR_VEND . '/splitting/splitting.min.js', 'jquery', '3.0.1', true );

        // Event Date Count Down Js
        wp_register_script( 'knob', SAASLAND_CORE_DIR_VEND . '/red-countdown/knob.js', array( 'jquery'), '1.2.11', true );
        wp_register_script( 'throttle', SAASLAND_CORE_DIR_VEND . '/red-countdown/throttle.js', array( 'jquery'), '1.1', true );
        wp_register_script( 'moment', SAASLAND_CORE_DIR_VEND . '/red-countdown/moment.js', array( 'jquery'), '2.9.0', true );
        wp_register_script( 'redcountdown', SAASLAND_CORE_DIR_VEND . '/red-countdown/redcountdown.js', array( 'jquery'), '1.0', true );
        wp_register_script( 'red-countdown-settings', SAASLAND_CORE_DIR_VEND . '/red-countdown/red-countdown-settings.js', array( 'jquery'), '1.0', true );
        wp_enqueue_script( 'wow', SAASLAND_CORE_DIR_VEND . '/wow/wow.min.js', array( 'jquery'), '1.1.3', true );

        wp_register_script( 'typed', SAASLAND_CORE_DIR_JS . '/typed.min.js', 'jquery', '1.0.0', true );
        wp_register_script( 'ajax-chimp', SAASLAND_CORE_DIR_JS . '/ajax-chimp.js', 'jquery', '1.0', true );
        wp_enqueue_script( 'appart-custom', SAASLAND_CORE_DIR_JS . '/appart-custom.js', array( 'jquery'), '1.0.0', true );

        if ( is_rtl() ) {
            wp_enqueue_script( 'saasland-main-rtl', SAASLAND_CORE_DIR_JS . '/main-rtl.js', 'jquery', '1.0', true);
        } else {
            wp_enqueue_script( 'saasland-main', SAASLAND_CORE_DIR_JS . '/main.js', 'jquery', '1.0', true);
        }
    }


    /**
     * Elementor Editor Style
     */
    function enqueue_elementor_editor_styles() {
        wp_enqueue_style( 'simple-line-icon', SAASLAND_CORE_DIR_VEND . '/simple-line-icon/simple-line-icons.min.css' );
        wp_enqueue_style( 'themify-icons', SAASLAND_CORE_DIR_VEND . '/themify-icon/themify-icons.css' );
        wp_enqueue_style( 'saasland-flaticons', SAASLAND_CORE_DIR_VEND . '/flaticon/flaticon.css' );
        wp_enqueue_style( 'saasland-elementor-editor', SAASLAND_CORE_DIR_CSS . '/elementor-editor.css' );
    }

    /**
     * Register Widget Styles
     *
     * Register custom styles required to run Saasland Core.
     *
     * @access public
     */

    function enqueue_elementor_scripts() {
        wp_enqueue_script( 'saasland-elementor', SAASLAND_CORE_DIR_JS . '/saasland-elementor.js', [ 'jquery', 'elementor-frontend'], '1.0', true );
    }


    public function enqueue_scripts() {
        wp_enqueue_script( 'lord-icon', 'https://cdn.lordicon.com/libs/mssddfmo/lord-icon-2.1.0.js"', array(), '2.1.0', true );
        wp_enqueue_style('saasland-custom', SAASLAND_CORE_DIR_CSS . '/custom.css' );
    }


}