<?php
namespace SaaslandCore\Widgets;

use Elementor\Group_Control_Image_Size;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use WP_Query;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Filterable Portfolio
 */
class Portfolio_simple extends Widget_Base {

    public function get_name() {
        return 'saasland_portfolio_simple';
    }

    public function get_title() {
        return __( 'Portfolio (Saasland)', 'saasland-hero' );
    }

    public function get_icon() {
        return 'eicon-posts-masonry';
    }

    public function get_style_depends() {
        return [ 'slick', 'slick-theme', 'saasland-core-portfolio' ];
    }

    public function get_script_depends() {
        return [ 'slick' ];
    }

    public function get_categories() {
        return [ 'saasland-elements' ];
    }

    protected function register_controls() {
        $this->saasland_elementor_content_control();
        $this->saasland_elementor_style_control();
    }

    /**
     * Name: saasland_elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @4.0.4
     * Package: @saasland
     * Author: DroitThemes
     * Developer: Arif Rahman
     */

    public function saasland_elementor_content_control() {

        //========================= Preset Skins ========================//
        $this->start_controls_section(
            'preset_skins_sec', [
                'label' => __( 'Preset Skins', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label' => esc_html__( 'Skin', 'saasland-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    '1' => [
                        'title' => __( '01 : Two Column Portfolio', 'saasland-core' ),
                        'icon' => 'portfolio1',
                    ],
                    '2' => [
                        'title' => __( '02 : Slider Portfolio', 'saasland-core' ),
                        'icon' => 'portfolio2',
                    ],
                    '3' => [
                        'title' => __( '03 : Architecture Homepage', 'saasland-core' ),
                        'icon' => 'portfolio3',
                    ],
                ],
                'default' => '1'
            ]
        );

        $this->end_controls_section(); //End Preset


        //========================= Section Contents ===========================//
        $this->start_controls_section(
            'sec_contents', [
                'label' => __( 'Contents', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => esc_html__( 'Title', 'saasland-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Work'
            ]
        );

        $this->add_control(
            'title_tag', [
                'label' => __( 'Title HTML Tag', 'saasland-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => saasland_el_select_title_tag(),
                'default' => 'h2',
            ]
        );

        $this->end_controls_section();// End Section Contents


        //========================= Query Settings ===========================//
        $this->start_controls_section(
            'portfolio_query', [
                'label' => __( 'Query Settings', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'select_cat', [
                'label' => __( 'Select Categories', 'saasland-core' ),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => Saasland_Core_Helper()->get_category_array('portfolio_cat'),
            ]
        );

        $this->add_control(
            'show_count', [
                'label' => esc_html__( 'Posts Per Page', 'saasland-core' ),
                'type' => Controls_Manager::NUMBER,
                'default' => '4'
            ]
        );

        $this->add_control(
            'order', [
                'label' => esc_html__( 'Order', 'saasland-core' ),
                'description' => esc_html__( '‘ASC‘ – ascending order from lowest to highest values (1, 2, 3; a, b, c). ‘DESC‘ – descending order from highest to lowest values (3, 2, 1; c, b, a).', 'saasland-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => 'ASC',
                    'DESC' => 'DESC'
                ],
                'default' => 'ASC'
            ]
        );

        $this->add_control(
            'orderby', [
                'label' => esc_html__( 'Order By', 'saasland-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' => 'None',
                    'ID' => 'ID',
                    'author' => 'Author',
                    'title' => 'Title',
                    'name' => 'Name (by post slug)',
                    'date' => 'Date',
                    'rand' => 'Random',
                    'comment_count' => 'Comment Count',
                ],
                'default' => 'none'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Image_Size::get_type(), [
                'name' => 'thumbnail', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
                'include' => [],
                'default' => 'full',
            ]
        );

        $this->end_controls_section(); //End Query Filter;

        $this->start_controls_section(
            'button_style', [
                'label' => __( 'Button', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'btn_label', [
                'label' => esc_html__('Button Label', 'saasland-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Discover More',
            ]
        );

            /*
         * See All Post
         */
        $this->add_control(
            'all_btn_label', [
                'label' => esc_html__('View All', 'saasland-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'See all Work',
                'condition' => [
                    'style' => [ '3' ]
                ]
            ]
        );

        $this->add_control(
            'all_btn_url', [
                'label' => esc_html__('View All', 'saasland-core'),
                'type' => Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ],
                'condition' => [
                    'style' => [ '3' ]
                ]
            ]
        );


        /*
         * Colors
         */
        $this->start_controls_tabs(
            'btn_style_tabs'
        );

        $this->start_controls_tab(
            'normal_btn',
            [
                'label' => __( 'Normal', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'normal_title_color',
            [
                'label' => __( 'Text Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .arch_learn_btn, .agency_learn_btn:before, .arch_learn_btn i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'hover_btn',
            [
                'label' => __( 'Hover', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'hover_title_color',
            [
                'label' => __( 'Text Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .arch_learn_btn:hover, .arch_learn_btn:hover:before, .arch_learn_btn:hover i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs(); // End Colors

        $this->end_controls_section(); // End Button section
    }


    /**
     * Name: saasland_elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @4.0.4
     * Package: @saasland
     * Author: DroitThemes
     * Developer: Arif Rahman
     */
    public function saasland_elementor_style_control() {

        //========================= Post Thumbnail =========================//
        $this->start_controls_section(
            'portfolio_image', [
                'label' => __( 'Featured Thumbnail', 'saasland-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'img_space_bottom', [
                'label' => __( 'Space Bottom', 'saasland-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => saasland_el_slider_range(),
                'selectors' => [
                    '{{WRAPPER}} .simple-portfolio-wrapper .portfolio .portfolio-img img' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(), [
                'name' => 'box_shadow',
                'label' => __( 'Box Shadow', 'saasland-core' ),
                'selector' => '{{WRAPPER}} .simple-portfolio-wrapper .portfolio .portfolio-img img',
            ]
        );

        $this->end_controls_section(); //End Post Thumbnail


        //======================== Style Contents =====================//
        $this->start_controls_section(
            'portfolio_content', [
                'label' => __( 'Content', 'saasland-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //======= Category Options
        $this->add_control(
            'cats_options', [
                'label' => __( 'Category Options', 'saasland-core' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'category_typography',
                'label' => __( 'Category Typography', 'saasland-core' ),
                'selector' => '{{WRAPPER}} .simple-portfolio-wrapper .portfolio-meta span',
            ]
        );

        $this->add_responsive_control(
            'cat_space_left', [
                'label' => __( 'Space between', 'saasland-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => saasland_el_slider_range(),
                'selectors' => [
                    '{{WRAPPER}} .simple-portfolio-wrapper .portfolio-meta span:not(:last-child)' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'cat_color', [
                'label' => __( 'Category Color', 'saasland-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .simple-portfolio-wrapper .portfolio-meta span' => 'color: {{VALUE}}',
                ],
            ]
        ); //End Category Options


        //=========== Heading Options
        $this->add_control(
            'heading_options', [
                'label' => __( 'Heading Options', 'saasland-core' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'item_title_typo',
                'label' => __( 'Category Typography', 'saasland-core' ),
                'selector' => '{{WRAPPER}} .simple-portfolio-wrapper .portfolio-title h3',
            ]
        );

        $this->add_control(
            'item_title_color', [
                'label' => __( 'Title Color', 'saasland-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .simple-portfolio-wrapper .portfolio-title h3' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'item_title_space_top', [
                'label' => __( 'Space Top', 'saasland-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => saasland_el_slider_range(),
                'selectors' => [
                    '{{WRAPPER}} .simple-portfolio-wrapper .portfolio-title h3' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section(); //End Style Contents


        //====================== Style Layout ============================//
        $this->start_controls_section(
            'style_layout', [
                'label' => __( 'Layout', 'saasland-core' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'layout_space_two_column', [
                'label' => __( 'Space Two Column', 'saasland-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => saasland_el_slider_range(),
                'selectors' => [
                    '{{WRAPPER}} .saasland-d-grid' => 'grid-column-gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'layout_space_two_row', [
                'label' => __( 'Space Two Row', 'saasland-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => saasland_el_slider_range(),
                'selectors' => [
                    '{{WRAPPER}} .saasland-d-grid' => 'grid-row-gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'layout_2nd_space_top', [
                'label' => __( '2nd Column Space Top', 'saasland-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => saasland_el_slider_range(),
                'selectors' => [
                    '{{WRAPPER}} .simple-portfolio-wrapper .portfolio:nth-child(2n)' => 'transform: translateY( {{SIZE}}{{UNIT}});',
                ],
            ]
        );

        $this->end_controls_section(); //End Style Layout

    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @4.0.4
     * Package: @saasland
     * Author: DroitThemes
     * Developer: Arif Rahman
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

        $btn_label      = !empty($settings['btn_label']) ? $settings['btn_label'] : ''; 
        $all_btn_label  = !empty($settings['all_btn_label']) ? $settings['all_btn_label'] : '';
        $all_btn_url    = !empty($settings['all_btn_url']) ? $settings['all_btn_url'] : '';

        $args = [
            'post_type'     => 'portfolio',
        ];

        if ( $show_count != '' ) {
            $args['posts_per_page']  = $show_count;
        }
        if ( $order != '' ) {
            $args['order']  = $order;
        }
        if ( $orderby != '' ) {
            $args['orderby']  = $orderby;
        }

        if ( is_array($select_cat) && !empty($select_cat) ) {
            $args['tax_query']  = [
                [
                    'taxonomy' => 'portfolio_cat',
                    'field' => 'id',
                    'terms' => $select_cat,
                ]
            ];
        }

        $portfolios = new \WP_Query( $args );

        $get_portfolios = get_posts($args);

        //=========== Template Parts
        include "templating/portfolio-simple/portfolio-{$settings['style']}.php";

    }

}