<?php
/**
 * Register Google fonts.
 *
 * @return string Google fonts URL for the theme.
 */
function saasland_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    $subsets   = '';

    /* Body font */
    if ( 'off' !== 'on' ) {
        $fonts[] = "Poppins:300,400,500,600,700,900";
    }

    $is_ssl = is_ssl() ? 'https' : 'http';

    if ( $fonts ) {
        $fonts_url = add_query_arg( array(
            'family' => urlencode( implode( '|', $fonts  ) ),
            'subset' => urlencode( $subsets ),
        ), "$is_ssl://fonts.googleapis.com/css" );
    }

    return $fonts_url;
}

function saasland_scripts() {
    $opt = get_option( 'saasland_opt' );
    $is_preloader = !empty($opt['is_preloader']) ? $opt['is_preloader'] : '';
    $footer_visibility = function_exists( 'get_field' ) ? get_field( 'footer_visibility' ) : '1';
    $footer_visibility = isset($footer_visibility) ? $footer_visibility : '1';

    /**
     * Register Stylesheets
     */
    wp_register_style( 'saasland-fonts', saasland_fonts_url(), array(), null );
    wp_register_style( 'saasland-elements', SAASLAND_DIR_CSS.'/elements.min.css', array('bootstrap') );
    wp_register_style( 'saasland-comments', SAASLAND_DIR_CSS.'/comments.min.css' );
    wp_register_style( 'saasland-blog', SAASLAND_DIR_CSS.'/blog.min.css' );
    wp_register_style( 'eleganticons',  SAASLAND_DIR_VEND.'/elagent/style.min.css' );
    wp_register_style( 'saasland-preloader', SAASLAND_DIR_CSS.'/pre-loader.min.css' );
    wp_register_style( 'saasland-footer', SAASLAND_DIR_CSS.'/footer.min.css' );
    wp_register_style( 'saasland-404', SAASLAND_DIR_CSS.'/404.min.css' );
    wp_register_style( 'saasland-owl.carousel', SAASLAND_DIR_CSS.'/saasland-owl.carousel.min.css' );
    wp_register_style( 'saasland-animate', SAASLAND_DIR_VEND . '/animation/animate.css' );
    wp_register_style( 'saasland-custom-animations',  SAASLAND_DIR_CSS.'/saasland-animations.min.css' );
    wp_register_style( 'mCustomScrollbar',  SAASLAND_DIR_VEND . '/scroll/jquery.mCustomScrollbar.min.css' );
    wp_register_style( 'saasland-elementor',  SAASLAND_DIR_CSS.'/elementor-override.min.css', array('elementor-frontend') );
    wp_register_style( 'saasland-portfolio',  SAASLAND_DIR_CSS.'/single-portfolio.min.css' );
    wp_register_style( 'saasland-job',  SAASLAND_DIR_CSS.'/single-job.min.css' );
    wp_register_style( 'nice-select',  SAASLAND_DIR_VEND.'/nice-select/nice-select.min.css' );
    wp_register_style( 'saasland-overlay-menu',  SAASLAND_DIR_CSS.'/overlay-menu.min.css', array( 'saasland-root' ) );
    wp_register_style( 'saasland-team',  SAASLAND_DIR_CSS.'/single-team.css' );
    wp_register_style( 'saasland-style-new',  SAASLAND_DIR_CSS.'/style-new.min.css' );
    wp_register_style( 'saasland-digital-agency', SAASLAND_DIR_CSS.'/digital-agency.min.css' );

    /**
     * Register Scripts
     */
    wp_register_script( 'nice-select', SAASLAND_DIR_VEND.'/nice-select/jquery.nice-select.min.js', array( 'jquery' ), '1.0', true );

    /**
     * Dark mode support css & js
     */
    if ( did_action('droitDark/loaded') ){
        wp_enqueue_style( 'saasland-dark-support',  SAASLAND_DIR_CSS.'/saasland-dark-support.css' );
        wp_enqueue_script( 'saasland-dark-support', SAASLAND_DIR_JS.'/saasland-dark-support.js', '', '1.0', true );
    }

    /**
     * Enqueueing Stylesheets
     */
    $font_load = 1;
    if ( class_exists('ReduxFrameworkPlugin') ) {
        $font_load = !empty( $opt['is_default_font'] ) ? 1 : '';
    }
    if( $font_load == 1 ){
        wp_enqueue_style( 'saasland-fonts' );
    }

    wp_enqueue_style( 'bootstrap',  SAASLAND_DIR_CSS.'/bootstrap.min.css' );
    wp_enqueue_style( 'font-awesome-5-free',  SAASLAND_DIR_VEND.'/font-awesome/css/all.css' );
    wp_enqueue_style( 'themify-icon',  SAASLAND_DIR_VEND.'/themify-icon/themify-icons.min.css' );
    wp_enqueue_style( 'saasland-elementor' );
    wp_register_style('saasland-remove-animation', SAASLAND_DIR_CSS.'/remove-animation.css');

    /**
     * Animation Library
     */
    $is_animation = isset($opt['is_anim']) ? $opt['is_anim'] : '1';

    if ( $is_animation == '1' ) {
        wp_enqueue_style( 'saasland-animate' );
        wp_enqueue_style( 'saasland-custom-animations' );
    } else {
        wp_enqueue_style('saasland-remove-animation');
    }

    /**
     * Single Portfolio CSS
     */
    if ( is_singular( 'portfolio' ) ) {
        wp_enqueue_style( 'saasland-portfolio' );
    }

    /**
     * Single Team CSS
     */
    if ( is_singular( 'team' ) ) {
        wp_enqueue_style( 'saasland-team' );
    }

    /**
     * Single Job / Service Page CSS
     */
    if ( is_singular( 'job' ) || is_singular( 'service' ) || is_page_template('page-job-apply-form.php') ) {
        wp_enqueue_style( 'saasland-job' );
    }

    wp_enqueue_style( 'magnific-popup',  SAASLAND_DIR_VEND.'/magnify-pop/magnific-popup.min.css' );
    wp_enqueue_style( 'eleganticons' );
    wp_enqueue_style( 'saasland-wpd',  SAASLAND_DIR_CSS.'/wpd-style.min.css' );
    wp_enqueue_style( 'saasland-main',  SAASLAND_DIR_CSS.'/style.min.css', array('bootstrap') );
    wp_enqueue_style( 'saasland-elements' );

    if ( is_page() ) {
        wp_deregister_style( 'saasland-blog' );
    }

    if ( is_home() || is_singular( 'post' ) || is_search() || is_archive() || is_singular('faq') ) {
        wp_enqueue_style( 'saasland-blog' );
    }

    wp_enqueue_style( 'saasland-comments' );

    if ( $is_preloader == '1' ) {
        wp_enqueue_style( 'saasland-preloader' );
    }

    if ( $footer_visibility == '1' ) {
        wp_enqueue_style( 'saasland-footer' );
    }

    if ( is_404() ) {
        wp_enqueue_style( 'saasland-404' );
        wp_deregister_style( 'saasland-custom-animations' );
        wp_deregister_style( 'saasland-animate' );
        wp_deregister_style( 'saasland-wpd' );
    }

    // Split Screen Page 
    if ( is_page_template( 'page-split.php' ) ) {
        wp_enqueue_style( 'multiscroll',  SAASLAND_DIR_VEND.'/multiscroll/jquery.multiscroll.css' );
        wp_enqueue_style( 'saasland-split-page',  SAASLAND_DIR_CSS.'/split-page.min.css', array( 'saasland-root' ) );
    }

    // Agency Colorful
    if ( is_page_template( 'page-agency-colorful.php' ) ) {
        wp_enqueue_style( 'saasland-pagepiling',  SAASLAND_DIR_VEND.'/pagepiling/jquery.pagepiling.css' );
        wp_enqueue_style( 'saasland-slick',  SAASLAND_DIR_VEND.'/slick/slick.css' );
        wp_enqueue_style( 'slick-theme',  SAASLAND_DIR_VEND.'/slick/slick-theme.min.css' );
        wp_enqueue_style( 'saasland-agency-colorful',  SAASLAND_DIR_CSS.'/agency-colorful.min.css', array( 'saasland-root' ) );
    }

    // Case Study page
    if ( is_singular( 'case_study' ) || is_post_type_archive( 'case_study' ) ) {
        wp_enqueue_style( 'saasland-cstudy', SAASLAND_DIR_CSS.'/cstudy.min.css' );
    }

    wp_enqueue_style( 'saasland-gutenberg',  SAASLAND_DIR_CSS.'/gutenberg.min.css' );

    if ( is_rtl() ) {
        wp_enqueue_style( 'saasland-rtl', SAASLAND_DIR_CSS . '/theme-rtl.min.css');
    }

    wp_enqueue_style( 'saasland-root', get_stylesheet_uri() );

    wp_enqueue_style( 'saasland-responsive', SAASLAND_DIR_CSS.'/responsive.min.css' );

    wp_enqueue_style( 'saasland-responsive2', SAASLAND_DIR_CSS.'/responsive-2.css' );


    // Inline Saasland Dynamic Render File
    require get_template_directory() . '/inc/saasland_inline_render.php';

    /**
     * Register JavaScript Files
     */
    wp_register_script( 'mCustomScrollbar', SAASLAND_DIR_VEND.'/scroll/jquery.mCustomScrollbar.concat.min.js', array( 'jquery' ), '3.1.13', true);


    /**
     * Enqueueing JavaScript Files
     */
    wp_enqueue_script( 'propper', SAASLAND_DIR_JS.'/propper.js', array( 'jquery' ), '1.0', true );

    wp_enqueue_script( 'bootstrap', SAASLAND_DIR_JS.'/bootstrap.min.js', array( 'jquery' ), '4.1.2', true );

    wp_enqueue_script( 'parallax-scroll', SAASLAND_DIR_VEND.'/sckroller/jquery.parallax-scroll.js', array( 'jquery' ), '1.0', true );

    wp_enqueue_script( 'magnific-popup', SAASLAND_DIR_VEND.'/magnify-pop/jquery.magnific-popup.min.js', array( 'jquery' ), '1.1.0', true );

    if ( is_page_template( 'page-job-apply-form.php' ) ) {
        wp_enqueue_style( 'nice-select' );
        wp_enqueue_script( 'nice-select' );
    }

    if ( is_page_template( 'page-split.php' ) ) {
        wp_enqueue_script( 'jquery-easings', SAASLAND_DIR_VEND.'/multiscroll/jquery.easings.min.js', array( 'jquery' ), '1.9.2', true);
        wp_enqueue_script( 'multiscroll', SAASLAND_DIR_VEND.'/multiscroll/multiscroll.responsiveExpand.min.js', array( 'jquery' ), '0.0.4', true);
        wp_enqueue_script( 'multiscroll-extensions', SAASLAND_DIR_VEND.'/multiscroll/jquery.multiscroll.extensions.min.js', array( 'jquery' ), '0.1.5', true);
        wp_enqueue_script( 'saasland-multi', SAASLAND_DIR_VEND.'/multiscroll/multi.js', array( 'jquery' ), '1.0', true);
    }

    // Agency Colorful
    if ( is_page_template( 'page-agency-colorful.php' ) ) {
        wp_enqueue_script( 'jquery-pagepiling', SAASLAND_DIR_VEND.'/pagepiling/jquery.pagepiling.js', array( 'jquery' ), '1.5.4', true);
        wp_enqueue_script( 'slick', SAASLAND_DIR_VEND.'/slick/slick.js', array( 'jquery' ), '1.0', true);
        wp_enqueue_script( 'agency-colorful', SAASLAND_DIR_JS.'/agency-colorful.js', array( 'jquery' ), '1.0', true);
    }

    // Love js
    if ( is_singular( 'case_study' ) ) {
        wp_enqueue_script( 'saasland-love', get_template_directory_uri() . '/assets/js/love.js', array( 'jquery' ), '1.0', true);
    }

    if ( class_exists( 'WooCommerce' ) ) {
        wp_register_style( 'saasland-shop', SAASLAND_DIR_CSS.'/shop.min.css' );
        wp_register_style( 'saasland-checkout', SAASLAND_DIR_CSS.'/checkout.min.css' );
        wp_register_style( 'saasland-shop-my-account', SAASLAND_DIR_CSS.'/shop-my_account.min.css' );

        wp_register_script( 'saasland-quick-view', SAASLAND_DIR_JS.'/saasland-quick-view.js', '', '1.0', true );

        if ( is_shop() || is_tax( 'product_cat' ) || is_singular( 'product' ) || is_tax( 'product_tag' ) || is_cart() ) {
            wp_enqueue_style( 'saasland-shop' );
        }

        if ( is_checkout() ) {
            wp_enqueue_style( 'saasland-checkout' );
        }

        if ( is_account_page() ) {
            wp_enqueue_style( 'saasland-shop-my-account' );
        }

        if ( function_exists( 'is_wishlist' ) ) {
            if ( is_wishlist() ) {
                wp_enqueue_style( 'saasland-shop' );
            }
        }

        if ( is_shop() || is_tax( 'product_cat' ) || is_tax( 'product_tag' ) ) {
            wp_enqueue_style( 'nice-select' );
            wp_enqueue_script( 'nice-select' );
            wp_enqueue_script( 'saasland-quick-view' );
        }
    }

    $mega_menus = new WP_Query(array(
        'post_type' => 'megamenu',
        'posts_per_page' => -1,
    ));



    $mega_menu_count = $mega_menus->post_count;
    if ( $mega_menu_count > 0  ) {
        wp_enqueue_style( 'mCustomScrollbar' );
        wp_enqueue_script( 'mCustomScrollbar');
    }

    wp_enqueue_script( 'saasland-custom-wp', SAASLAND_DIR_JS.'/custom-wp.js', array( 'jquery' ), '1.0', true );

    wp_localize_script( 'saasland-custom-wp', 'local_strings', array(
        'ajax_url' => admin_url( 'admin-ajax.php' ),
        'theme_directory' => get_template_directory_uri() 
    ));

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
}
add_action( 'wp_enqueue_scripts', 'saasland_scripts' );

/**
 * Admin dashboard style and scripts
 */
add_action( 'admin_enqueue_scripts', function() {
    global $pagenow;    
    wp_enqueue_style( 'saasland-admin', SAASLAND_DIR_CSS.'/admin.min.css' );
    wp_enqueue_script( 'saasland-admin', SAASLAND_DIR_JS.'/saasland-admin.js', array('jquery'), '1.0.0', true );
    wp_register_style( 'eleganticons',  SAASLAND_DIR_VEND.'/elagent/style.min.css' );
    wp_register_style( 'saasland-fonts', saasland_fonts_url(), array(), null);
    if ( $pagenow == 'themes.php' ) {
        wp_enqueue_style( 'saasland-fonts' );
        wp_enqueue_style( 'eleganticons' );
        wp_enqueue_style( 'saasland-admin-dashboard', SAASLAND_DIR_CSS.'/admin-dashboard.min.css' );
    }
});

/**
 * Gutenberg editor assets
 */
add_action( 'enqueue_block_assets', function() {
    $font_load2 = 1;
    if ( class_exists('ReduxFrameworkPlugin') ) {
        $font_load2 = !empty( $opt['is_default_font'] ) ? 1 : '';
    }
    if( $font_load2 == 1 ){
        wp_enqueue_style( 'saasland-editor-fonts', saasland_fonts_url(), array(), null );
    }
    wp_enqueue_style( 'font-awesome-5-free',  SAASLAND_DIR_VEND.'/font-awesome/css/all.css' );
});